# generated by datamodel-codegen:
#   filename:  error.json
#   timestamp: 2021-06-26T19:10:08+00:00

from __future__ import annotations

from typing import List

from locatieserver.schema.base import LocatieserverBaseModel


class Error(LocatieserverBaseModel):
    metadata: List[str]
    msg: str
    code: int


class ErrorResponse(LocatieserverBaseModel):
    error: Error
